@@ -5,12 +5,12 @@
 # import pytest
 
 
-from contraptions import contraptions
+from contraptions import add, subtract
 
 # @pytest.fixture
 # def response():
 
 
 def test_content():
-    assert contraptions.add(1, 2) == 3
-    assert contraptions.subtract(2, 1) == 1
+    assert add(1, 2) == 3
+    assert subtract(2, 1) == 1
